| Latest Release                                      | Version                                             | Documentation                                    | Last Commit                                                     | Activity
| :--------------------------------------: | :-------------:                             | :--------------------------:                        | :----:                                              | :------:
| [![Github Release][release_shield]][github_release] | [![Github Version][version_shield]][github_version] | [![Documentation Status][doc_shield]][doc] | [![Github Last Commit][last_commit_shield]][github_last_commit] | [![Github commit activity][activity_shield]][github_activity]

[release_shield]: https://img.shields.io/github/release/contagon/SiPANN.svg
[version_shield]: https://badge.fury.io/gh/contagon%SiPANN.svg
[doc_shield]: https://readthedocs.org/projects/sipann/badge/?version=latest
[last_commit_shield]: https://img.shields.io/github/last-commit/contagon/SiPANN.svg
[activity_shield]: https://img.shields.io/github/commit-activity/y/contagon/SiPANN.svg

[github_release]: https://github.com/contagon/SiPANN/releases/latest
[github_version]: https://github.com/contagon/SiPANN/releases/latest
[doc]: https://sipann.readthedocs.io/en/latest/?badge=latest
[github_last_commit]: https://github.com/contagon/SiPANN/commits/master
[github_activity]: https://github.com/contagon/SiPANN/graphs/commit-activity

# SiP-ANN
Artifical Neural Networks for use with Silicon Photonics

## Installation Instructions

**Note:** This package is currently in its alpha development stage. Expect frequent changes, breaks, bug fixes, features, etc.

After the repository is cloned, install a "development" version into your current python module library using

```pip install -e .```


from the main directory. Be sure to include the `.` at the end.

This development version allows you to make changes to this code directly (or pull changes from GitHub) without having to reinstall the package each time.

You should then be able to run the examples and tutorials in the examples folder, or even call the package from any other python file.

Bibtex citation:

```
@misc{SiP-ANN_2019,
	title={SiP-ANN},
	author={Alec M. Hammond, Easton Potokar, Ryan M. Camacho},
	year={2019},
	publisher={GitHub},
	howpublished={{https://github.com/contagon/SiP-ANN}}
}
```


